@@ -236,6 +236,29 @@ TEST(MsgsTest, ConvertMathMassMatrix3ToMsgs)
   EXPECT_EQ(ignition::math::Pose3d::Zero, msgs::Convert(msg.pose()));
 }
 
+/////////////////////////////////////////////////
+TEST(MsgsTest, ConvertMathSphericalCoordinatesToMsgs)
+{
+  auto msg = msgs::Convert(
+      math::SphericalCoordinates(
+      math::SphericalCoordinates::SurfaceType::EARTH_WGS84,
+      IGN_DTOR(1.1), IGN_DTOR(2.2), 3.3, IGN_DTOR(0.4)));
+
+  EXPECT_EQ(msgs::SphericalCoordinates::EARTH_WGS84, msg.surface_model());
+  EXPECT_DOUBLE_EQ(1.1, msg.latitude_deg());
+  EXPECT_DOUBLE_EQ(2.2, msg.longitude_deg());
+  EXPECT_DOUBLE_EQ(3.3, msg.elevation());
+  EXPECT_DOUBLE_EQ(0.4, msg.heading_deg());
+
+  auto math = msgs::Convert(msg);
+
+  EXPECT_EQ(math::SphericalCoordinates::EARTH_WGS84, math.Surface());
+  EXPECT_DOUBLE_EQ(1.1, math.LatitudeReference().Degree());
+  EXPECT_DOUBLE_EQ(2.2, math.LongitudeReference().Degree());
+  EXPECT_DOUBLE_EQ(3.3, math.ElevationReference());
+  EXPECT_DOUBLE_EQ(0.4, math.HeadingOffset().Degree());
+}
+
 /////////////////////////////////////////////////
 TEST(UtilityTest, ConvertStringMsg)
 {
@@ -316,6 +339,133 @@ TEST(UtilityTest, ConvertFloat)
   EXPECT_DOUBLE_EQ(s, 0.999f);
 }
 
+
+/////////////////////////////////////////////////
+TEST(UtilityTest, ConvertFuelMetadata)
+{
+  msgs::FuelMetadata metaMsg;
+  std::string modelConfigInput, worldConfigInput;
+
+  // test ConvertFuelMetadata(string, msgs::FuelMetadata)
+  {
+    EXPECT_FALSE(msgs::ConvertFuelMetadata(modelConfigInput, metaMsg));
+
+    metaMsg.Clear();
+    modelConfigInput = "<test/>";
+    EXPECT_FALSE(msgs::ConvertFuelMetadata(modelConfigInput, metaMsg));
+
+    metaMsg.Clear();
+    modelConfigInput = "<model>test</model>";
+    EXPECT_FALSE(msgs::ConvertFuelMetadata(modelConfigInput, metaMsg));
+
+    // Test <model>
+    metaMsg.Clear();
+    modelConfigInput = R"(
+      <model>
+        <name>test_model</name>
+      </model>
+    )";
+    EXPECT_FALSE(msgs::ConvertFuelMetadata(modelConfigInput, metaMsg));
+
+    metaMsg.Clear();
+    modelConfigInput = R"(<?xml version='1.0'?>
+  <model>
+    <sdf version='1.7'>model.sdf</sdf>
+    <name>test_model</name>
+    <version>3</version>
+    <description>A model for testing</description>
+    <author>
+      <name>Foo Bar</name>
+      <email>foo@bar.org</email>
+    </author>
+    <depend>
+      <model>
+        <uri>model://some_model</uri>
+      </model>
+    </depend>
+  </model>
+)";
+
+    EXPECT_TRUE(msgs::ConvertFuelMetadata(modelConfigInput, metaMsg));
+    EXPECT_EQ("test_model", metaMsg.name());
+    EXPECT_EQ(3, metaMsg.version());
+    EXPECT_EQ("A model for testing", metaMsg.description());
+    EXPECT_EQ("model.sdf", metaMsg.model().file());
+    EXPECT_EQ("sdf", metaMsg.model().file_format().name());
+    EXPECT_EQ(1, metaMsg.model().file_format().version().major());
+    EXPECT_EQ(7, metaMsg.model().file_format().version().minor());
+    EXPECT_EQ(1, metaMsg.authors().size());
+    EXPECT_EQ("Foo Bar", metaMsg.authors(0).name());
+    EXPECT_EQ("foo@bar.org", metaMsg.authors(0).email());
+    EXPECT_EQ(1, metaMsg.dependencies().size());
+    EXPECT_EQ("model://some_model", metaMsg.dependencies(0).uri());
+
+    // Test <world>
+    metaMsg.Clear();
+    worldConfigInput = R"(<?xml version='1.0'?>
+  <world>
+    <sdf version='1.7'>world.sdf</sdf>
+    <name>test_world</name>
+    <version>2</version>
+    <description>A world for testing</description>
+  </world>
+)";
+    EXPECT_TRUE(msgs::ConvertFuelMetadata(worldConfigInput, metaMsg));
+    EXPECT_EQ("test_world", metaMsg.name());
+    EXPECT_EQ(2, metaMsg.version());
+    EXPECT_EQ("A world for testing", metaMsg.description());
+    EXPECT_EQ("world.sdf", metaMsg.world().file());
+    EXPECT_EQ("sdf", metaMsg.world().file_format().name());
+    EXPECT_EQ(1, metaMsg.world().file_format().version().major());
+    EXPECT_EQ(7, metaMsg.world().file_format().version().minor());
+    EXPECT_EQ(0, metaMsg.authors().size());
+    EXPECT_EQ(0, metaMsg.dependencies().size());
+  }
+
+  // test ConvertFuelMetadata(msgs::FuelMetadata, string)
+  {
+    std::string modelConfig;
+
+    // Test <world>
+    metaMsg.Clear();
+    metaMsg.mutable_world()->set_file("world.sdf");
+    EXPECT_FALSE(msgs::ConvertFuelMetadata(metaMsg, modelConfig));
+
+    metaMsg.set_name("test_world");
+    metaMsg.set_description("A world for testing");
+    metaMsg.set_version(2);
+    metaMsg.mutable_world()->mutable_file_format()->set_name("sdf");
+    metaMsg.mutable_world()->mutable_file_format()
+           ->mutable_version()->set_major(1);
+    metaMsg.mutable_world()->mutable_file_format()
+           ->mutable_version()->set_minor(7);
+    EXPECT_TRUE(msgs::ConvertFuelMetadata(metaMsg, modelConfig));
+
+    EXPECT_EQ(worldConfigInput, modelConfig);
+
+    // Test <model>
+    metaMsg.Clear();
+    metaMsg.mutable_model()->set_file("model.sdf");
+    EXPECT_FALSE(msgs::ConvertFuelMetadata(metaMsg, modelConfig));
+
+    metaMsg.set_name("test_model");
+    metaMsg.set_description("A model for testing");
+    metaMsg.set_version(3);
+    metaMsg.mutable_model()->mutable_file_format()->set_name("sdf");
+    metaMsg.mutable_model()->mutable_file_format()
+           ->mutable_version()->set_major(1);
+    metaMsg.mutable_model()->mutable_file_format()
+           ->mutable_version()->set_minor(7);
+    EXPECT_TRUE(msgs::ConvertFuelMetadata(metaMsg, modelConfig));
+
+    metaMsg.add_authors()->set_name("Foo Bar");
+    metaMsg.mutable_authors(0)->set_email("foo@bar.org");
+    metaMsg.add_dependencies()->set_uri("model://some_model");
+    EXPECT_TRUE(msgs::ConvertFuelMetadata(metaMsg, modelConfig));
+    EXPECT_EQ(modelConfigInput, modelConfig);
+  }
+}
+
 /////////////////////////////////////////////////
 TEST(UtilityTest, ConvertTimePoint)
 {
@@ -451,6 +601,21 @@ TEST(MsgsTest, SetMassMatrix3)
   EXPECT_EQ(ignition::math::Pose3d::Zero, msgs::Convert(msg.pose()));
 }
 
+/////////////////////////////////////////////////
+TEST(MsgsTest, SetSphericalCoordinates)
+{
+  msgs::SphericalCoordinates msg;
+  msgs::Set(&msg, math::SphericalCoordinates(
+      math::SphericalCoordinates::SurfaceType::EARTH_WGS84,
+      IGN_DTOR(1.1), IGN_DTOR(2.2), 3.3, IGN_DTOR(0.4)));
+
+  EXPECT_EQ(msgs::SphericalCoordinates::EARTH_WGS84, msg.surface_model());
+  EXPECT_DOUBLE_EQ(1.1, msg.latitude_deg());
+  EXPECT_DOUBLE_EQ(2.2, msg.longitude_deg());
+  EXPECT_DOUBLE_EQ(3.3, msg.elevation());
+  EXPECT_DOUBLE_EQ(0.4, msg.heading_deg());
+}
+
 /////////////////////////////////////////////////
 TEST(MsgsTest, SetStringMsg)
 {
